@@ -32,6 +32,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	"eachfile.h"
 #include	"missing.h"
 #include	"utilities.h"
+#include	"xml.h"
 #include	"elcerror.h"
 #include	"elcerror_p.h"
 #include	"utilities_p.h"
@@ -39,6 +40,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	"elcwft_p.h"
 #include	"eachfile_p.h"
 #include	"missing_p.h"
+#include	"xml_p.h"
 #ifdef		ELC_FIND_LEAKS
 #include	"leakfind.h"
 #endif
@@ -98,7 +100,7 @@ static void get_currdb_checksum(options *opts, char sumbuf[MD5_DIGEST_LENGTH])
     MD5_Final(sumbuf, &context);
 }
 
-static void show_currdb_checksum(options *opts, char *sumbuf, size_t n)
+static void show_currdb_checksum_abbrev(options *opts, char *sumbuf, size_t n)
 {
     char	*fname	 = opts->currdbname;
 
@@ -109,6 +111,18 @@ static void show_currdb_checksum(options *opts, char *sumbuf, size_t n)
     puts(fname);
 }
 
+static void show_currdb_checksum_xml(options *opts, const char *checksum_type,
+				     char *sumbuf, size_t n)
+{
+    char	*fname	 = opts->currdbname;
+
+    fprintf(stdout, "<checksum type=\"%s\" file=\"%s\">",
+	    checksum_type, fname);
+    hexprint(stdout, sumbuf, n);
+    XML_END_PRINT(stdout, "checksum");
+    putc('\n', stdout);
+}
+
 int main(int argc, char *argv[])
 {
     options	opts;
@@ -116,7 +130,11 @@ int main(int argc, char *argv[])
 
     options_init(&opts);
     options_set(&opts, argc, argv);
-    options_announce(&opts);
+    if (opts.output == OUTPUT_XML) {
+      xml_declaration(stdout);
+      xml_start_report(stdout, &opts);
+    }
+    options_announce(stdout, &opts);
 
     /* todo: use shared file locking with fcntl */
     if (opts.do_check)
@@ -137,12 +155,24 @@ int main(int argc, char *argv[])
 	check_for_missing(&opts);	/* only do this after new current cdb
 					   is closed (i.e. cdb_make is done) */
       else if (opts.verbose > 0)
-	puts(PROGNAME ": not doing update, so no check for missing files");
+	fputs(PROGNAME ": not doing update, so no check for missing files",
+	      stderr);
       
       close_known_cdb(&opts);
     }
-    if (opts.do_update)
-      show_currdb_checksum(&opts, newdb_checksum, sizeof(newdb_checksum));
+    if (opts.do_update) {
+      if (opts.output == OUTPUT_XML)
+	show_currdb_checksum_xml(&opts, "MD5",
+				 newdb_checksum, sizeof(newdb_checksum));
+      else
+	show_currdb_checksum_abbrev(&opts,
+				    newdb_checksum, sizeof(newdb_checksum));
+    }
+    
+    if (opts.output == OUTPUT_XML) {
+      XML_END_PRINT(stdout, "report");
+      putc('\n', stdout);
+    }
 
     options_destroy(&opts);
 #ifdef		ELC_FIND_LEAKS
