@@ -16,6 +16,11 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #ifndef	INT_OPTIONS_H
 #define	INT_OPTIONS_H
 
+enum integrit_output {
+  OUTPUT_ABBREV,		/* terse, abbreviated output */
+  OUTPUT_XML,			/* XML output */
+};  
+
 typedef struct options {
   char			*conffile;	/* from argv, so don't free */
   char			*knowndbname;
@@ -26,6 +31,7 @@ typedef struct options {
   hashtbl_t		*ruleset;
   int			verbose;
   unsigned long		default_flags;
+  enum integrit_output	output;	/* type of output */
   unsigned		do_check: 1;	/* test files against known-state db */
   unsigned		do_update: 1;	/* generate current-state db */
 } options;
